
package interfazgrafica11;

import javax.swing.JLabel;
import javax.swing.JSpinner;

public class Componentes {
      
      private JSpinner jSpinnerNumeros;   
      private JSpinner jSpinnerGeneros;
      private JSpinner jSpinnerFechas;
      private JLabel jLabelNumeros;
      private JLabel jLabelGeneros;
      private JLabel jLabelFechas;
    
    public JSpinner getjSpinnerNumeros() {
        return jSpinnerNumeros;
    }

    public void setjSpinnerNumeros(JSpinner jSpinnerNumeros) {
        this.jSpinnerNumeros = jSpinnerNumeros;
    }    

    public JSpinner getjSpinnerGeneros() {
        return jSpinnerGeneros;
    }

    public void setjSpinnerGeneros(JSpinner jSpinnerGeneros) {
        this.jSpinnerGeneros = jSpinnerGeneros;
    }
    
    public JSpinner getjSpinnerFechas() {
        return jSpinnerFechas;
    }

    public void setjSpinnerFechas(JSpinner jSpinnerFechas) {
        this.jSpinnerFechas = jSpinnerFechas;
    } 

    public JLabel getjLabelNumeros() {
        return jLabelNumeros;
    }

    public void setjLabelNumeros(JLabel jLabelNumeros) {
        this.jLabelNumeros = jLabelNumeros;
    }

    public JLabel getjLabelGeneros() {
        return jLabelGeneros;
    }

    public void setjLabelGeneros(JLabel jLabelGeneros) {
        this.jLabelGeneros = jLabelGeneros;
    }

    public JLabel getjLabelFechas() {
        return jLabelFechas;
    }

    public void setjLabelFechas(JLabel jLabelFechas) {
        this.jLabelFechas = jLabelFechas;
    }
}
